import 'package:flutter/material.dart';

extension OpenContextExtensions on BuildContext {
  // Screen size properties
  double get width => mediaQuery.size.width;
  double get height => mediaQuery.size.height;
  Size get size => mediaQuery.size;

  // Screen type properties
  bool get isMobile => width <= 500.0;
  bool get isTablet => width >= 650.0 && width < 1024.0;
  bool get isSmallTablet => width > 500.0 && width < 650.0;
  bool get isDesktop => width >= 1024.0;
  bool get isSmall => width >= 560.0 && width < 850.0;

  // Theme and styling
  ThemeData get theme => Theme.of(this);
  TextTheme get textTheme => theme.textTheme;
  ColorScheme get colorScheme => theme.colorScheme;
  DefaultTextStyle get defaultTextStyle => DefaultTextStyle.of(this);

  // Media query data
  MediaQueryData get mediaQuery => MediaQuery.of(this);

  // Widget-related properties
  NavigatorState get navigator => Navigator.of(this);
  FocusScopeNode get focusScope => FocusScope.of(this);
  ScaffoldState get scaffold => Scaffold.of(this);
  ScaffoldMessengerState get scaffoldMessenger => ScaffoldMessenger.of(this);
}
