import 'dart:math';

import 'package:google_maps_flutter/google_maps_flutter.dart';

extension OpenGoogleMapsExtensions on GoogleMap {
  /// Calculates the bounding box (LatLngBounds) from a list of LatLng points.
  LatLngBounds getBoundsFromLatLngList(List<LatLng> points) {
    assert(points.isNotEmpty, 'The points list cannot be empty.');

    double minLat = points.first.latitude;
    double maxLat = points.first.latitude;
    double minLng = points.first.longitude;
    double maxLng = points.first.longitude;

    for (final point in points) {
      minLat = min(minLat, point.latitude);
      maxLat = max(maxLat, point.latitude);
      minLng = min(minLng, point.longitude);
      maxLng = max(maxLng, point.longitude);
    }

    return LatLngBounds(
      northeast: LatLng(maxLat, maxLng),
      southwest: LatLng(minLat, minLng),
    );
  }

  /// Calculates the geographical center of a list of LatLng points.
  LatLng calculateCenter(List<LatLng> points) {
    assert(points.isNotEmpty, 'The points list cannot be empty.');

    final total = points.fold<LatLng>(
      const LatLng(0.0, 0.0),
      (acc, point) => LatLng(
        acc.latitude + point.latitude,
        acc.longitude + point.longitude,
      ),
    );

    return LatLng(
      total.latitude / points.length,
      total.longitude / points.length,
    );
  }
}
