import 'package:open_exts/open_exts.dart';

extension OpenIntExtensions on int {
  Iterable<int> to(int other, [bool inclusive = true]) sync* {
    if (this == other) {
      if (inclusive) yield this;
      return;
    }

    final step = this < other ? 1 : -1;
    for (int i = this;
        inclusive ? (i != other + step) : (i != other);
        i += step) {
      yield i;
    }
  }

  /// Converts the integer to a binary string with optional padding, grouping, and separation.
  /// - [length]: Total length of the binary string, padded with zeros if needed.
  /// - [groupSize]: Number of binary digits per group for separation.
  /// - [separator]: String used to separate binary groups.
  String toBinary(
    int length, {
    int groupSize = 4,
    String separator = ',',
  }) {
    assert(length > 0, 'Length must be greater than zero.');
    assert(groupSize > 0, 'Group size must be greater than zero.');

    return toRadixString(2)
        .padLeft(length, '0')
        .splitByLength(groupSize)
        .join(separator);
  }
}
